package com.yunzhi.marketing.sample.controller;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.yunzhi.marketing.base.BaseController;
import com.yunzhi.marketing.base.ResponseBean;
import com.yunzhi.marketing.sample.entity.TaSampleContact;
import com.yunzhi.marketing.sample.service.ITaSampleContactService;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestMethod;
import org.springframework.web.bind.annotation.RequestParam;
import org.springframework.web.bind.annotation.ResponseBody;
import org.springframework.web.bind.annotation.RestController;

/**
 * <p>
    * 样例与联系人关联表  前端控制器
    * </p>
 *
 * @author fxf
 * @since 2020-03-18
 */
@RestController
@RequestMapping("/")
public class TaSampleContactController extends BaseController {

    private final Logger logger = LoggerFactory.getLogger(TaSampleContactController.class);

    @Autowired
    public ITaSampleContactService iTaSampleContactService;


    /**
     * 分页查询列表
     * @param pageNum
     * @param pageSize
     * @return
     */
    @RequestMapping(value="/taSampleContact",method= RequestMethod.GET)
    public ResponseBean taSampleContactList(@RequestParam(value ="pageNum",defaultValue = "1") Integer pageNum,
                                            @RequestParam(value ="pageSize",defaultValue = "10") Integer pageSize){
        ResponseBean responseBean = new ResponseBean();
        try {
            //使用分页插件
		    IPage<TaSampleContact> pg = new Page<>(pageNum, pageSize);
            QueryWrapper<TaSampleContact> queryWrapper = new QueryWrapper<>();
            queryWrapper.orderByDesc("create_date");

            IPage<TaSampleContact> result = iTaSampleContactService.page(pg, queryWrapper);
            responseBean.addSuccess(result);
        }catch (Exception e){
            e.printStackTrace();
            logger.error("taSampleContactList -=- {}",e.toString());
            responseBean.addError(e.getMessage());
        }
        return responseBean;
    }

    /**
     * 保存对象
     * @param taSampleContact 实体对象
     * @return
     */
    @RequestMapping(value="/taSampleContact",method= RequestMethod.POST)
    public ResponseBean taSampleContactAdd(@RequestBody TaSampleContact taSampleContact){
        ResponseBean responseBean = new ResponseBean();
        try {
            if (iTaSampleContactService.save(taSampleContact)){
                responseBean.addSuccess(taSampleContact);
            }else {
                responseBean.addError("fail");
            }
        }catch (Exception e){
            e.printStackTrace();
            logger.error("taSampleContactAdd -=- {}",e.toString());
            responseBean.addError(e.getMessage());
        }
        return responseBean;
    }

    /**
     * 根据id删除对象
     * @param id  实体ID
     */
    @ResponseBody
    @RequestMapping(value="/taSampleContact/{id}", method= RequestMethod.DELETE)
    public ResponseBean taSampleContactDelete(@PathVariable Integer id){
        ResponseBean responseBean = new ResponseBean();
        try {
            if(iTaSampleContactService.removeById(id)){
                responseBean.addSuccess("success");
            }else {
                responseBean.addError("fail");
            }
        }catch (Exception e){
            e.printStackTrace();
            logger.error("taSampleContactDelete -=- {}",e.toString());
            responseBean.addError(e.getMessage());
        }
        return responseBean;
    }

    /**
     * 修改对象
     * @param id  实体ID
     * @param taSampleContact 实体对象
     * @return
     */
    @RequestMapping(value="/taSampleContact/{id}",method= RequestMethod.PUT)
    public ResponseBean taSampleContactUpdate(@PathVariable Integer id,
                                        @RequestBody TaSampleContact taSampleContact){
        ResponseBean responseBean = new ResponseBean();
        try {
            if (iTaSampleContactService.updateById(taSampleContact)){
                responseBean.addSuccess(taSampleContact);
            }else {
                responseBean.addError("fail");
            }
        }catch (Exception e){
            e.printStackTrace();
            logger.error("taSampleContactUpdate -=- {}",e.toString());
            responseBean.addError(e.getMessage());
        }
        return responseBean;
    }

    /**
     * 根据id查询对象
     * @param id  实体ID
     */
    @RequestMapping(value="/taSampleContact/{id}",method= RequestMethod.GET)
    public ResponseBean taSampleContactGet(@PathVariable Integer id){
        ResponseBean responseBean = new ResponseBean();
        try {
            responseBean.addSuccess(iTaSampleContactService.getById(id));
        }catch (Exception e){
            e.printStackTrace();
            logger.error("taSampleContactDelete -=- {}",e.toString());
            responseBean.addError(e.getMessage());
        }
        return responseBean;
    }
}
